@@ -547,7 +547,7 @@ gsm_systemd_set_session_idle (GsmSystemd *manager,
                               gboolean       is_idle)
 {
     GError         *error;
-    char           *session_path;
+    char           *session_path = NULL;
     DBusMessage    *message;
     DBusMessage    *reply;
     DBusError       dbus_error;
@@ -564,6 +564,8 @@ gsm_systemd_set_session_idle (GsmSystemd *manager,
 
     gsm_systemd_get_session_path (dbus_g_connection_get_connection (manager->priv->dbus_connection), &session_path);
 
+    g_return_if_fail (session_path != NULL);
+
     g_debug ("Updating Systemd idle status: %d", is_idle);
     message = dbus_message_new_method_call (SD_NAME,
                                             session_path,
@@ -600,7 +602,9 @@ gsm_systemd_can_switch_user (GsmSystemd *manager)
 {
     GError  *error;
     char    *session_id = NULL;
+#ifdef HAVE_SYSTEMD
     char    *seat_id = NULL;
+#endif
     int      ret = 0;
 
     error = NULL;
@@ -725,13 +729,150 @@ gsm_systemd_can_stop (GsmSystemd *manager)
     return can_stop;
 }
 
+gboolean
+gsm_systemd_can_hibernate (GsmSystemd *manager)
+{
+  gboolean res;
+  gchar   *value;
+  gboolean can_hibernate;
+  GError  *error;
+  
+  error = NULL;
+  
+  if (!gsm_systemd_ensure_sd_connection (manager, &error)) {
+    g_warning ("Could not connect to Systemd: %s",
+	       error->message);
+    g_error_free (error);
+    return FALSE;
+  }
+  
+  res = dbus_g_proxy_call_with_timeout (manager->priv->sd_proxy,
+					"CanHibernate",
+					INT_MAX,
+					&error,
+					G_TYPE_INVALID,
+					G_TYPE_STRING, &value,
+					G_TYPE_INVALID);
+  if (res == FALSE) {
+    g_warning ("Could not make DBUS call: %s",
+	       error->message);
+    g_error_free (error);
+    return FALSE;
+  }
+  
+  can_hibernate = g_strcmp0 (value, "yes") == 0 ||
+  g_strcmp0 (value, "challenge") == 0;
+  g_free (value);
+  return can_hibernate;
+}
+
+gboolean
+gsm_systemd_can_suspend (GsmSystemd *manager)
+{
+  gboolean res;
+  gchar   *value;
+  gboolean can_suspend;
+  GError  *error;
+  
+  error = NULL;
+  
+  if (!gsm_systemd_ensure_sd_connection (manager, &error)) {
+    g_warning ("Could not connect to Systemd: %s",
+	       error->message);
+    g_error_free (error);
+    return FALSE;
+  }
+  
+  res = dbus_g_proxy_call_with_timeout (manager->priv->sd_proxy,
+					"CanSuspend",
+					INT_MAX,
+					&error,
+					G_TYPE_INVALID,
+					G_TYPE_STRING, &value,
+					G_TYPE_INVALID);
+  if (res == FALSE) {
+    g_warning ("Could not make DBUS call: %s",
+	       error->message);
+    g_error_free (error);
+    return FALSE;
+  }
+  
+  can_suspend = g_strcmp0 (value, "yes") == 0 ||
+  g_strcmp0 (value, "challenge") == 0;
+  g_free (value);
+  return can_suspend;
+}
+
+void
+gsm_systemd_attempt_hibernate (GsmSystemd *manager)
+{
+  gboolean res;
+  GError  *error;
+  
+  error = NULL;
+  
+  if (!gsm_systemd_ensure_sd_connection (manager, &error)) {
+    g_warning ("Could not connect to Systemd: %s",
+	       error->message);
+    g_error_free (error);
+    return;
+  }
+  
+  res = dbus_g_proxy_call_with_timeout (manager->priv->sd_proxy,
+					"Hibernate",
+					INT_MAX,
+					&error,
+                                        G_TYPE_BOOLEAN, TRUE, /* interactive */
+					G_TYPE_INVALID,
+					G_TYPE_INVALID);
+  if (res == FALSE) {
+    g_warning ("Could not make DBUS call: %s",
+	       error->message);
+    g_error_free (error);
+    return;
+  }
+  
+}
+
+void
+gsm_systemd_attempt_suspend (GsmSystemd *manager)
+{
+  gboolean res;
+  GError  *error;
+  
+  error = NULL;
+  
+  if (!gsm_systemd_ensure_sd_connection (manager, &error)) {
+    g_warning ("Could not connect to Systemd: %s",
+	       error->message);
+    g_error_free (error);
+    return;
+  }
+  
+  res = dbus_g_proxy_call_with_timeout (manager->priv->sd_proxy,
+					"Suspend",
+					INT_MAX,
+					&error,
+                                        G_TYPE_BOOLEAN, TRUE, /* interactive */
+                                        G_TYPE_INVALID,
+					G_TYPE_INVALID);
+  if (res == FALSE) {
+    g_warning ("Could not make DBUS call: %s",
+	       error->message);
+    g_error_free (error);
+    return;
+  }
+}
+
 gchar *
 gsm_systemd_get_current_session_type (GsmSystemd *manager)
 {
     GError   *gerror;
-    int       session_id;
+    gchar    *session_id = NULL;
     gchar    *session_class = NULL;
+#ifdef HAVE_SYSTEMD
     int       res;
+#endif
 
     gerror = NULL;
 
@@ -755,6 +896,8 @@ gsm_systemd_get_current_session_type (GsmSystemd *manager)
         g_warning ("Could not get Systemd session class!");
         return NULL;
     }
+
+    g_free (session_id);
 #endif
 
     return session_class;
