@@ -29,11 +29,11 @@
 #include <glib.h>
 #include <dbus/dbus-glib.h>
 
-#define SM_DBUS_NAME      "org.mate.SessionManager"
-#define SM_DBUS_PATH      "/org/mate/SessionManager"
-#define SM_DBUS_INTERFACE "org.mate.SessionManager"
+#define SM_DBUS_NAME      "org.gnome.SessionManager"
+#define SM_DBUS_PATH      "/org/gnome/SessionManager"
+#define SM_DBUS_INTERFACE "org.gnome.SessionManager"
 
-#define SM_CLIENT_DBUS_INTERFACE "org.mate.SessionManager.ClientPrivate"
+#define SM_CLIENT_DBUS_INTERFACE "org.gnome.SessionManager.ClientPrivate"
 
 #ifdef __GNUC__
 #define UNUSED_VARIABLE __attribute__ ((unused))
